<?php 
namespace FoodBook;
/**
 *
 * @package     Foodbook
 * @author      ThemeLooks
 * @copyright   2020 ThemeLooks
 * @license     GPL-2.0-or-later
 *
 *
 */

class Hooks {

  function __construct() {

    // Foodbook shop page shortcode register hook
    add_shortcode( 'foodbook_products', [ __CLASS__, 'foodbook_shortcode' ] );

    // Foodbook delivery ability checker shortcode register hook
    add_shortcode( 'foodbook_delivery_ability_checker', [ __CLASS__, 'foodbook_delivery_ability_checker_shortcode' ] );

    // Foodbook shop page Template include filter hook
    add_filter( 'template_include', [ __CLASS__, 'foodbook_page_template'], 99 );

    // register_taxonomy for specialoffer post types.
    add_action( 'init', [ __CLASS__, 'foodbook_specialoffer_taxonomy'], 0 );

    // Add Body class on foodbook woocommerce page action hook
    add_filter( 'body_class', [ __CLASS__, 'add_body_class'] );

    // Js template hook in footer action hook
    add_action( 'wp_footer', [ __CLASS__, 'fb_js_template'] );

    // Login redirect filter hook
    add_filter( 'login_redirect', [ __CLASS__, 'foodbook_login_redirect' ], 10, 3 );

    // Login failed redirect
    add_action( 'wp_login_failed', [ __CLASS__, 'foodbook_login_failed_redirect' ] );

    // Add custom userr roles
    add_filter( 'init', [ __CLASS__, 'foodbook_add_roles' ] );

    //
    add_action( 'admin_init', [$this, 'foodbook_no_admin_access'], 100 );

    // Location modal
    add_action( 'wp_footer', [ __CLASS__, 'location_modal'] );


  }

  /**
   * Foodbook shop page shortcode register
   *
   * 
   */
  
  public static function foodbook_shortcode( $atts ) {

    $attr = shortcode_atts( array(
      'col'     => '3',
      'layout'  => 'grid',
      'sidebar' => 'yes',
      'search'  => 'yes',
      'cat'     => '',
      'padding_top'     => '0px',
      'padding_bottom'  => '0px'
    ), $atts );


    global $foodbookAttr;

    $foodbookAttr = $attr;

    ob_start();
   
    include FOODBOOK_DIR_PATH.'view/template-part-woo-items.php';
    
    return ob_get_clean();
   
  }

  /**
   * foodbook_delivery_ability_checker_shortcode 
   * @param  string $atts
   * @return html form
   */
  public static function foodbook_delivery_ability_checker_shortcode( $atts ) {

    $attr = shortcode_atts( array(
      'button_text'     => esc_html__( 'Search', 'foodbook' ),
    ), $atts );

    ob_start();
    \Foodbook\Inc\Ability_Checker_Form::form_for_shortcode( esc_html( $attr['button_text'] ) );
    return ob_get_clean();

  } 


  /**
   * Foodbook shop page Template include
   *
   * 
   */
  
   
  public static function foodbook_page_template( $template ) {
   
    $options = get_option('foodbook_options');

    $shop_page            = !empty( $options['shop-page'] ) ? $options['shop-page'] : 'foodbook';
    $branch_manager_page  = !empty( $options['branch-manager'] ) ? $options['branch-manager'] : 'branch-manager';
    $kitchen_manager_page = !empty( $options['kitchen-manager'] ) ? $options['kitchen-manager'] : 'kitchen-manager';
    $delivery_page        = !empty( $options['delivery'] ) ? $options['delivery'] : 'delivery';
    $admin_page           = !empty( $options['admin'] ) ? $options['admin'] : 'admin';


    // Woo Items
    if ( is_page( $shop_page )  ) {

        $new_template = FOODBOOK_DIR_PATH.'view/template-woo-items.php';

        if ( '' != $new_template ) {
            return $new_template ;
        }
    }
    
    // Manager Admin 
    if ( is_page( $admin_page )  ) {

        $new_template = FOODBOOK_DIR_PATH.'frontend-admin/templates/template-admin.php';

        if ( '' != $new_template ) {
            return $new_template ;
        }
    }
    // Branch Manager 
    if ( is_page( $branch_manager_page )  ) {

        $new_template = FOODBOOK_DIR_PATH.'frontend-admin/templates/template-branch-management.php';

        if ( '' != $new_template ) {
            return $new_template ;
        }
    }
    // kitchen Admin 
    if ( is_page( $kitchen_manager_page )  ) {

        $new_template = FOODBOOK_DIR_PATH.'frontend-admin/templates/template-kitchen-management.php';

        if ( '' != $new_template ) {
            return $new_template ;
        }
    }

    // Delivery Admin 
    if ( is_page( $delivery_page )  ) {

        $new_template = FOODBOOK_DIR_PATH.'frontend-admin/templates/template-delivery-management.php';

        if ( '' != $new_template ) {
            return $new_template ;
        }
    }


    return $template;

  }

  /**
   * Register.
   *
   * @see register_taxonomy for specialoffer post types.
   * 
   */

  
  public static function foodbook_specialoffer_taxonomy() {

      $args = array(
          'label'        => esc_html__( 'Special Offer', 'foodbook' ),
          'public'       => true,
          'rewrite'      => array( 'slug' => 'special-offer' ),
          'hierarchical' => true
      );

      register_taxonomy( 'specialoffer', 'product', $args );

  }


  /**
   *
   * Add Body class on foodbook woocommerce page
   * 
   * 
   */

  public static function add_body_class( $classes ) {

    // add checkout page body class
    if( is_checkout() ) {

      $classes = array_merge( $classes, array( 'foodbook-checkout' ) );

    }
    // add account page body class
    if( is_account_page() ) {
      $classes = array_merge( $classes, array( 'foodbook-checkout foodbook-account' ) );
    }

    return $classes;
  }


  /**
   *
   * Js template hook in footer
   * 
   * 
   */  
  public static function fb_js_template() {
    
    include FOODBOOK_DIR_PATH.'view/template-modal-wrapper.php';
    include FOODBOOK_DIR_PATH.'view/template-modal-steps.php';
    include FOODBOOK_DIR_PATH.'view/template-modal-product-content.php';
    include FOODBOOK_DIR_PATH.'view/template-modal-cart-content.php';
    include FOODBOOK_DIR_PATH.'view/template-modal-checkout.php';
    include FOODBOOK_DIR_PATH.'view/template-modal-loginreg.php';
    include FOODBOOK_DIR_PATH.'view/template-modal-reviews.php';
    include FOODBOOK_DIR_PATH.'view/template-modal-billing-summary.php';
    include FOODBOOK_DIR_PATH.'view/template-modal-alert.php';

    include FOODBOOK_DIR_PATH.'frontend-admin/js-templates/template-order-modal.php';

  }

/**
 * foodbook_login_redirect 
 * @param  [type] $redirect_to 
 * @param  [type] $request     
 * @param  [type] $user        
 * @return [type]              
 */
public static function foodbook_login_redirect( $redirect_to, $request, $user ) {

    $options = get_option('foodbook_options');

    $branch_manager_page  = !empty( $options['branch-manager'] ) ? $options['branch-manager'] : 'branch-manager';
    $kitchen_manager_page = !empty( $options['kitchen-manager'] ) ? $options['kitchen-manager'] : 'kitchen-manager';
    $delivery_page        = !empty( $options['delivery'] ) ? $options['delivery'] : 'delivery';


    //is there a user to check?
    if ( isset( $user->roles ) && is_array( $user->roles ) ) {
        //check for admins
        if ( in_array( 'administrator', $user->roles ) ) {
            // redirect them to the default place
            return $redirect_to;
        } elseif( in_array( 'branch_manager', $user->roles ) ) {
          return home_url( esc_html( $branch_manager_page ) );
        }elseif( in_array( 'kitchen_manager', $user->roles ) ){
          return home_url( esc_html( $kitchen_manager_page ) );
        }elseif( in_array( 'delivery_boy', $user->roles ) ) {
          return home_url( esc_html( $delivery_page ) );
        } else {
            return $redirect_to;
        }
    } else {
        return $redirect_to;
    }

}

/**
 * foodbook_login_failed_redirect
 * login failed redirect
 * @return 
 */
public static function foodbook_login_failed_redirect() {

  $options = get_option('foodbook_options');

  $admin_page  = !empty( $options['admin'] ) ? $options['admin'] : 'admin';

  wp_redirect( site_url( esc_html( $admin_page ) ) ); 

}

/**
 * foodbook_add_roles
 * add custom role
 * @return 
 */
public static function foodbook_add_roles() {

  add_role( 'kitchen_manager', esc_html__( 'Kitchen Manager', 'foodbook' ), get_role( 'subscriber' )->capabilities );
  add_role( 'branch_manager', esc_html__( 'Branch Manager', 'foodbook' ), get_role( 'subscriber' )->capabilities );
  add_role( 'delivery_boy', esc_html__( 'Delivery Boy', 'foodbook' ), get_role( 'subscriber' )->capabilities );

}



/**
 * foodbook_no_admin_access
 * prevent wp admin access
 * @return 
 * 
 */

public function foodbook_no_admin_access() {

  $options = get_option('foodbook_options');

  $admin_page  = !empty( $options['admin'] ) ? $options['admin'] : 'admin';


  if ( is_admin() && ! current_user_can( 'administrator' ) &&
  ! ( defined( 'DOING_AJAX' ) && DOING_AJAX ) ) {

    wp_redirect( site_url( esc_html( $admin_page ) ) );
    exit;

  }

}
/**
 * [location_modal description]
 * @return [type] [description]
 */
public static function location_modal() {

  $modalShow = get_option('foodbook_options');
  $popupActive = isset( $modalShow['location-popup-active'] ) ? $modalShow['location-popup-active'] : '';
  $availabilityCheckerActive = isset( $modalShow['availability-checker-active'] ) ? $modalShow['availability-checker-active'] : '';

  if( !$popupActive || !$availabilityCheckerActive ) {
    return;
  }

  
  $getPages = !empty( $modalShow['availability-checker-modal'] ) ? $modalShow['availability-checker-modal'] : 'foodbook';

  if( !is_page( $getPages ) ) {
    return;
  }

  ?>
  <div class="fb__wrapper orderadmin_popup_modal fb_delivery_availability_checker" id="orderadmin_popup_modal">
    <div class="fb_popup_modal open" style="display: block">
      <div class="fb_modal_wrap fb_modal_location">
        <div class="fb_modal">
          <div class="fb_modal_inner">
            <!-- Close Modal -->
            <span class="fb_close_modal">
              <img src="<?php echo FOODBOOK_DIR_URL.'assets/img/icon/close.svg'; ?>" alt="<?php esc_attr_e( 'close', 'foodbook' ); ?>" />
            </span>
            <?php 
            // Form
            \Foodbook\Inc\Ability_Checker_Form::form();
            ?>
          </div>
        </div>
      </div>
    </div>
  </div>
  <?php
}


}

// Hooks class init
new Hooks();